@@ -1,9 +1,10 @@
+
 assign("rbf.cv",
-  function(sigma, z, coordinates, n.neigh, func){
+  function(eta, z, coordinates, n.neigh, func){
   rbf.pred <- as.data.frame(matrix(NA,nrow= length(z), ncol=4))
   colnames(rbf.pred) <- c("x","y","var1.pred","var1.var")
   for(i in 1:(length(z))){                                                
-  rbf.pred[i,3] <- rbf(sigma, z, coordinates=coordinates[-i,], newdata=matrix(coordinates[i,],nrow=1), n.neigh, func)[,3]
+  rbf.pred[i,3] <- rbf(eta, z, coordinates=coordinates[-i,], newdata=coordinates[i,], n.neigh, func)[,3]
   }
 RMSPE <-  sqrt(sum((rbf.pred$var1.pred-z)^2)/length(z))
 RMSPE
